pub struct ExecutionFlowConfig {
pub handlers: Vec<String>,
pub chains: HashMap<String, Vec<String>>,
pub paths: HashMap<String, PrefixConfig>,
}Fields
handlers: Vec<String>chains: HashMap<String, Vec<String>>paths: HashMap<String, PrefixConfig>Path keys can be based on different data types. i.e. URL paths, IP, mac addr, RPC paths, etc. They hold what handlers should be executed in the ‘PrefixConfig’ associated.